from ..reports.dataclasses import FFLogsActor
from .page import FFLogsPage, FFLogsPageIterator, FFLogsPaginationIterator

__all__ = [
    'FFLogsPage',
    'FFLogsPageIterator',
    'FFLogsPaginationIterator',

    'FFLogsActor',
]
